scoretools.get_measure_that_starts_with_container
=================================================

.. autofunction:: abjad.tools.scoretools.get_measure_that_starts_with_container.get_measure_that_starts_with_container
